@@ -318,22 +318,22 @@ func (s *schemaInfoCache) Get(schemaVersion []byte) (schema Schema, err error) {
 		return schema, nil
 	}
 
-	pbSchema, err := s.client.lookupService.GetSchema(s.topic, schemaVersion)
+	//	cache missed, try to use lookupService to find schema info
+	lookupSchema, err := s.client.lookupService.GetSchema(s.topic, schemaVersion)
+	if err != nil {
+		return nil, err
+	}
+	schema, err = NewSchema(
+		//	lookupSchema.SchemaType is internal package SchemaType type,
+		//	we need to cast it to pulsar.SchemaType as soon as we use it in current pulsar package
+		SchemaType(lookupSchema.SchemaType),
+		lookupSchema.Data,
+		lookupSchema.Properties,
+	)
 	if err != nil {
 		return nil, err
 	}
 
-	if pbSchema == nil {
-		err = fmt.Errorf("schema not found for topic: [ %v ], schema version : [ %v ]", s.topic, schemaVersion)
-		return nil, err
-	}
-
-	var properties = internal.ConvertToStringMap(pbSchema.Properties)
-
-	schema, err = NewSchema(SchemaType(*pbSchema.Type), pbSchema.SchemaData, properties)
-	if err != nil {
-		return nil, err
-	}
 	s.add(key, schema)
 	return schema, nil
 }
@@ -760,6 +760,7 @@ func (pc *partitionConsumer) AckIDList(msgIDs []MessageID) error {
 				position := newPosition(msgID)
 				if convertedMsgID.ack() {
 					pendingAcks[position] = nil
+					pc.metrics.ProcessingTime.Observe(float64(time.Now().UnixNano()-convertedMsgID.receivedTime.UnixNano()) / 1.0e9)
 				} else if pc.options.enableBatchIndexAck {
 					pendingAcks[position] = convertedMsgID.tracker.getAckBitSet()
 				}
@@ -785,6 +786,8 @@ func (pc *partitionConsumer) AckIDList(msgIDs []MessageID) error {
 		return toAckError(map[error][]MessageID{errors.New("consumer state is closed"): validMsgIDs})
 	}
 
+	pc.metrics.AcksCounter.Add(float64(len(validMsgIDs)))
+
 	req := &ackListRequest{
 		errCh:  make(chan error),
 		msgIDs: toMsgIDDataList(pendingAcks),
