@@ -22,6 +22,8 @@ import (
 	"fmt"
 	"time"
 
+	"github.com/apache/pulsar-client-go/pulsar/internal"
+
 	"github.com/apache/pulsar-client-go/pulsar/backoff"
 
 	"github.com/apache/pulsar-client-go/pulsar/log"
@@ -126,7 +128,7 @@ func (r *dlqRouter) run() {
 				Properties:          properties,
 				EventTime:           msg.EventTime(),
 				ReplicationClusters: msg.replicationClusters,
-			}, func(messageID MessageID, producerMessage *ProducerMessage, err error) {
+			}, func(_ MessageID, _ *ProducerMessage, err error) {
 				if err == nil {
 					r.log.WithField("msgID", msgID).Debug("Succeed to send message to DLQ")
 					// The Producer ack might be coming from the connection go-routine that
@@ -165,12 +167,12 @@ func (r *dlqRouter) getProducer(schema Schema) Producer {
 
 	// Retry to create producer indefinitely
 	bo := r.backOffPolicyFunc()
-	for {
+	opFn := func() (Producer, error) {
 		opt := r.policy.ProducerOptions
 		opt.Topic = r.policy.DeadLetterTopic
 		opt.Schema = schema
 		if opt.Name == "" {
-			opt.Name = fmt.Sprintf("%s-%s-%s-DLQ", r.topicName, r.subscriptionName, r.consumerName)
+			opt.Name = fmt.Sprintf("%s-%s-%s-%s-DLQ", r.topicName, r.subscriptionName, r.consumerName, generateRandomName())
 		}
 		opt.initialSubscriptionName = r.policy.InitialSubscriptionName
 
@@ -179,15 +181,17 @@ func (r *dlqRouter) getProducer(schema Schema) Producer {
 		if r.policy.ProducerOptions.CompressionType == NoCompression {
 			opt.CompressionType = LZ4
 		}
-		producer, err := r.client.CreateProducer(opt)
-
-		if err != nil {
-			r.log.WithError(err).Error("Failed to create DLQ producer")
-			time.Sleep(bo.Next())
-			continue
-		} else {
-			r.producer = producer
-			return producer
-		}
+		return r.client.CreateProducer(opt)
 	}
+
+	res, err := internal.Retry(context.Background(), opFn, func(err error) time.Duration {
+		r.log.WithError(err).Error("Failed to create DLQ producer")
+		return bo.Next()
+	})
+
+	if err == nil {
+		r.producer = res
+	}
+
+	return res
 }
