@@ -57,7 +57,7 @@ func (c *mockedLookupRPCClient) NewConsumerID() uint64 {
 	return 1
 }
 
-func (c *mockedLookupRPCClient) RequestToAnyBroker(requestID uint64, cmdType pb.BaseCommand_Type,
+func (c *mockedLookupRPCClient) RequestToAnyBroker(_ uint64, cmdType pb.BaseCommand_Type,
 	message proto.Message) (*RPCResult, error) {
 	assert.Equal(c.t, cmdType, pb.BaseCommand_LOOKUP)
 
@@ -77,16 +77,16 @@ func (c *mockedLookupRPCClient) RequestToAnyBroker(requestID uint64, cmdType pb.
 	}, nil
 }
 
-func (c *mockedLookupRPCClient) RequestToHost(serviceNameResolver *ServiceNameResolver, requestID uint64,
+func (c *mockedLookupRPCClient) RequestToHost(_ *ServiceNameResolver, requestID uint64,
 	cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
 	return c.RequestToAnyBroker(requestID, cmdType, message)
 }
 
-func (c *mockedLookupRPCClient) LookupService(URL string) LookupService {
+func (c *mockedLookupRPCClient) LookupService(_ string) LookupService {
 	return nil
 }
 
-func (c *mockedLookupRPCClient) Request(logicalAddr *url.URL, physicalAddr *url.URL, requestID uint64,
+func (c *mockedLookupRPCClient) Request(logicalAddr *url.URL, physicalAddr *url.URL, _ uint64,
 	cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
 	assert.Equal(c.t, cmdType, pb.BaseCommand_LOOKUP)
 	expectedRequest := &c.expectedRequests[0]
@@ -108,14 +108,20 @@ func (c *mockedLookupRPCClient) Request(logicalAddr *url.URL, physicalAddr *url.
 	}, nil
 }
 
-func (c *mockedLookupRPCClient) RequestOnCnx(cnx Connection, requestID uint64, cmdType pb.BaseCommand_Type,
-	message proto.Message) (*RPCResult, error) {
+func (c *mockedLookupRPCClient) RequestWithCnxKeySuffix(_ *url.URL, _ *url.URL,
+	_ int32, _ uint64, _ pb.BaseCommand_Type, _ proto.Message) (*RPCResult, error) {
 	assert.Fail(c.t, "Shouldn't be called")
 	return nil, nil
 }
 
-func (c *mockedLookupRPCClient) RequestOnCnxNoWait(cnx Connection, cmdType pb.BaseCommand_Type,
-	message proto.Message) error {
+func (c *mockedLookupRPCClient) RequestOnCnx(_ Connection, _ uint64, _ pb.BaseCommand_Type,
+	_ proto.Message) (*RPCResult, error) {
+	assert.Fail(c.t, "Shouldn't be called")
+	return nil, nil
+}
+
+func (c *mockedLookupRPCClient) RequestOnCnxNoWait(_ Connection, _ pb.BaseCommand_Type,
+	_ proto.Message) error {
 	assert.Fail(c.t, "Shouldn't be called")
 	return nil
 }
@@ -128,7 +134,7 @@ func TestLookupSuccess(t *testing.T) {
 	url, err := url.Parse("pulsar://example:6650")
 	assert.NoError(t, err)
 	serviceNameResolver := NewPulsarServiceNameResolver(url)
-
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t: t,
 
@@ -138,6 +144,7 @@ func TestLookupSuccess(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -149,9 +156,8 @@ func TestLookupSuccess(t *testing.T) {
 			},
 		},
 	}
-
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, serviceNameResolver, false, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, serviceNameResolver, false, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.NoError(t, err)
@@ -165,6 +171,7 @@ func TestTlsLookupSuccess(t *testing.T) {
 	url, err := url.Parse("pulsar+ssl://example:6651")
 	assert.NoError(t, err)
 	serviceNameResolver := NewPulsarServiceNameResolver(url)
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t: t,
 
@@ -174,6 +181,7 @@ func TestTlsLookupSuccess(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -187,7 +195,7 @@ func TestTlsLookupSuccess(t *testing.T) {
 	}
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
 
-	ls := NewLookupService(mockedClient, url, serviceNameResolver, true, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, serviceNameResolver, true, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.NoError(t, err)
@@ -201,6 +209,7 @@ func TestLookupWithProxy(t *testing.T) {
 	url, err := url.Parse("pulsar://example:6650")
 	assert.NoError(t, err)
 	serviceNameResolver := NewPulsarServiceNameResolver(url)
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t: t,
 
@@ -210,6 +219,7 @@ func TestLookupWithProxy(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -223,7 +233,7 @@ func TestLookupWithProxy(t *testing.T) {
 		},
 	}
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, serviceNameResolver, false, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, serviceNameResolver, false, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.NoError(t, err)
@@ -236,7 +246,7 @@ func TestLookupWithProxy(t *testing.T) {
 func TestTlsLookupWithProxy(t *testing.T) {
 	url, err := url.Parse("pulsar+ssl://example:6651")
 	assert.NoError(t, err)
-
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t: t,
 
@@ -246,6 +256,7 @@ func TestTlsLookupWithProxy(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -260,7 +271,7 @@ func TestTlsLookupWithProxy(t *testing.T) {
 	}
 	resolver := NewPulsarServiceNameResolver(url)
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, resolver, true, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, resolver, true, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.NoError(t, err)
@@ -273,7 +284,7 @@ func TestTlsLookupWithProxy(t *testing.T) {
 func TestLookupWithRedirect(t *testing.T) {
 	url, err := url.Parse("pulsar://example:6650")
 	assert.NoError(t, err)
-
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t:           t,
 		expectedURL: "pulsar://broker-2:6650",
@@ -284,6 +295,7 @@ func TestLookupWithRedirect(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 			{
 				RequestId:              proto.Uint64(2),
@@ -309,7 +321,7 @@ func TestLookupWithRedirect(t *testing.T) {
 	}
 	resolver := NewPulsarServiceNameResolver(url)
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, resolver, false, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, resolver, false, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.NoError(t, err)
@@ -322,7 +334,7 @@ func TestLookupWithRedirect(t *testing.T) {
 func TestTlsLookupWithRedirect(t *testing.T) {
 	url, err := url.Parse("pulsar+ssl://example:6651")
 	assert.NoError(t, err)
-
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t:           t,
 		expectedURL: "pulsar+ssl://broker-2:6651",
@@ -333,6 +345,7 @@ func TestTlsLookupWithRedirect(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 			{
 				RequestId:              proto.Uint64(2),
@@ -359,7 +372,7 @@ func TestTlsLookupWithRedirect(t *testing.T) {
 
 	resolver := NewPulsarServiceNameResolver(url)
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, resolver, true, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, resolver, true, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.NoError(t, err)
@@ -372,7 +385,7 @@ func TestTlsLookupWithRedirect(t *testing.T) {
 func TestLookupWithInvalidUrlResponse(t *testing.T) {
 	url, err := url.Parse("pulsar://example:6650")
 	assert.NoError(t, err)
-
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t: t,
 
@@ -382,6 +395,7 @@ func TestLookupWithInvalidUrlResponse(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -396,7 +410,7 @@ func TestLookupWithInvalidUrlResponse(t *testing.T) {
 	}
 	resolver := NewPulsarServiceNameResolver(url)
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, resolver, false, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, resolver, false, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.Error(t, err)
@@ -406,7 +420,7 @@ func TestLookupWithInvalidUrlResponse(t *testing.T) {
 func TestLookupWithLookupFailure(t *testing.T) {
 	url, err := url.Parse("pulsar://example:6650")
 	assert.NoError(t, err)
-
+	kvs := make([]*pb.KeyValue, 0)
 	mockedClient := &mockedLookupRPCClient{
 		t: t,
 
@@ -416,6 +430,7 @@ func TestLookupWithLookupFailure(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				Authoritative:          proto.Bool(false),
 				AdvertisedListenerName: proto.String(""),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -429,7 +444,7 @@ func TestLookupWithLookupFailure(t *testing.T) {
 
 	resolver := NewPulsarServiceNameResolver(url)
 	metricsProvider := NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer)
-	ls := NewLookupService(mockedClient, url, resolver, false, "", log.DefaultNopLogger(), metricsProvider)
+	ls := NewLookupService(mockedClient, url, resolver, false, "", kvs, log.DefaultNopLogger(), metricsProvider)
 
 	lr, err := ls.Lookup("my-topic")
 	assert.Error(t, err)
@@ -458,7 +473,7 @@ func (m mockedPartitionedTopicMetadataRPCClient) NewConsumerID() uint64 {
 }
 
 func (m mockedPartitionedTopicMetadataRPCClient) RequestToAnyBroker(requestID uint64, cmdType pb.BaseCommand_Type,
-	message proto.Message) (*RPCResult, error) {
+	_ proto.Message) (*RPCResult, error) {
 	assert.Equal(m.t, cmdType, pb.BaseCommand_PARTITIONED_METADATA)
 
 	expectedRequest := &m.expectedRequests[0]
@@ -477,30 +492,36 @@ func (m mockedPartitionedTopicMetadataRPCClient) RequestToAnyBroker(requestID ui
 	}, nil
 }
 
-func (m mockedPartitionedTopicMetadataRPCClient) Request(logicalAddr *url.URL, physicalAddr *url.URL, requestID uint64,
-	cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
+func (m mockedPartitionedTopicMetadataRPCClient) Request(_ *url.URL, _ *url.URL, _ uint64,
+	_ pb.BaseCommand_Type, _ proto.Message) (*RPCResult, error) {
 	assert.Fail(m.t, "Shouldn't be called")
 	return nil, nil
 }
 
-func (m mockedPartitionedTopicMetadataRPCClient) RequestOnCnxNoWait(cnx Connection, cmdType pb.BaseCommand_Type,
-	message proto.Message) error {
+func (m *mockedPartitionedTopicMetadataRPCClient) RequestWithCnxKeySuffix(_ *url.URL, _ *url.URL,
+	_ int32, _ uint64, _ pb.BaseCommand_Type, _ proto.Message) (*RPCResult, error) {
+	assert.Fail(m.t, "Shouldn't be called")
+	return nil, nil
+}
+
+func (m mockedPartitionedTopicMetadataRPCClient) RequestOnCnxNoWait(_ Connection, _ pb.BaseCommand_Type,
+	_ proto.Message) error {
 	assert.Fail(m.t, "Shouldn't be called")
 	return nil
 }
 
-func (m mockedPartitionedTopicMetadataRPCClient) RequestOnCnx(cnx Connection, requestID uint64,
-	cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
+func (m mockedPartitionedTopicMetadataRPCClient) RequestOnCnx(_ Connection, _ uint64,
+	_ pb.BaseCommand_Type, _ proto.Message) (*RPCResult, error) {
 	assert.Fail(m.t, "Shouldn't be called")
 	return nil, nil
 }
 
-func (m *mockedPartitionedTopicMetadataRPCClient) RequestToHost(serviceNameResolver *ServiceNameResolver,
+func (m *mockedPartitionedTopicMetadataRPCClient) RequestToHost(_ *ServiceNameResolver,
 	requestID uint64, cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
 	return m.RequestToAnyBroker(requestID, cmdType, message)
 }
 
-func (m *mockedPartitionedTopicMetadataRPCClient) LookupService(URL string) LookupService {
+func (m *mockedPartitionedTopicMetadataRPCClient) LookupService(_ string) LookupService {
 	return nil
 }
 
@@ -509,6 +530,7 @@ func TestGetPartitionedTopicMetadataSuccess(t *testing.T) {
 	assert.NoError(t, err)
 	serviceNameResolver := NewPulsarServiceNameResolver(url)
 
+	kvs := make([]*pb.KeyValue, 0)
 	ls := NewLookupService(&mockedPartitionedTopicMetadataRPCClient{
 		t: t,
 
@@ -525,7 +547,7 @@ func TestGetPartitionedTopicMetadataSuccess(t *testing.T) {
 				Response:   pb.CommandPartitionedTopicMetadataResponse_Success.Enum(),
 			},
 		},
-	}, url, serviceNameResolver, false, "", log.DefaultNopLogger(),
+	}, url, serviceNameResolver, false, "", kvs, log.DefaultNopLogger(),
 		NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer))
 
 	metadata, err := ls.GetPartitionedTopicMetadata("my-topic")
@@ -539,6 +561,7 @@ func TestLookupSuccessWithMultipleHosts(t *testing.T) {
 	assert.NoError(t, err)
 	serviceNameResolver := NewPulsarServiceNameResolver(url)
 
+	kvs := make([]*pb.KeyValue, 0)
 	ls := NewLookupService(&mockedLookupRPCClient{
 		t: t,
 
@@ -548,6 +571,7 @@ func TestLookupSuccessWithMultipleHosts(t *testing.T) {
 				Topic:                  proto.String("my-topic"),
 				AdvertisedListenerName: proto.String(""),
 				Authoritative:          proto.Bool(false),
+				Properties:             kvs,
 			},
 		},
 		mockedResponses: []pb.CommandLookupTopicResponse{
@@ -558,7 +582,7 @@ func TestLookupSuccessWithMultipleHosts(t *testing.T) {
 				BrokerServiceUrl: proto.String("pulsar://broker-1:6650"),
 			},
 		},
-	}, url, serviceNameResolver, false, "", log.DefaultNopLogger(),
+	}, url, serviceNameResolver, false, "", kvs, log.DefaultNopLogger(),
 		NewMetricsProvider(4, map[string]string{}, prometheus.DefaultRegisterer))
 
 	lr, err := ls.Lookup("my-topic")
@@ -575,7 +599,7 @@ type MockHTTPClient struct {
 
 func (c *MockHTTPClient) Close() {}
 
-func (c *MockHTTPClient) Get(endpoint string, obj interface{}, params map[string]string) error {
+func (c *MockHTTPClient) Get(endpoint string, obj interface{}, _ map[string]string) error {
 	if strings.Contains(endpoint, HTTPLookupServiceBasePathV1) || strings.Contains(endpoint,
 		HTTPLookupServiceBasePathV2) {
 		return mockHTTPGetLookupResult(obj)
