@@ -18,6 +18,7 @@
 package internal
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"net/url"
@@ -63,6 +64,9 @@ type RPCClient interface {
 	RequestToHost(serviceNameResolver *ServiceNameResolver, requestID uint64,
 		cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error)
 
+	RequestWithCnxKeySuffix(logicalAddr *url.URL, physicalAddr *url.URL, cnxKeySuffix int32, requestID uint64,
+		cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error)
+
 	Request(logicalAddr *url.URL, physicalAddr *url.URL, requestID uint64,
 		cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error)
 
@@ -87,11 +91,12 @@ type rpcClient struct {
 	lookupService           LookupService
 	urlLookupServiceMapLock sync.RWMutex
 	urlLookupServiceMap     map[string]LookupService
+	lookupProperties        []*pb.KeyValue
 }
 
 func NewRPCClient(serviceURL *url.URL, pool ConnectionPool,
 	requestTimeout time.Duration, logger log.Logger, metrics *Metrics,
-	listenerName string, tlsConfig *TLSOptions, authProvider auth.Provider) RPCClient {
+	listenerName string, tlsConfig *TLSOptions, authProvider auth.Provider, lookupProperties []*pb.KeyValue) RPCClient {
 	c := rpcClient{
 		pool:                pool,
 		requestTimeout:      requestTimeout,
@@ -101,6 +106,7 @@ func NewRPCClient(serviceURL *url.URL, pool ConnectionPool,
 		tlsConfig:           tlsConfig,
 		authProvider:        authProvider,
 		urlLookupServiceMap: make(map[string]LookupService),
+		lookupProperties:    lookupProperties,
 	}
 	lookupService, err := c.NewLookupService(serviceURL)
 	if err != nil {
@@ -115,27 +121,26 @@ func (c *rpcClient) requestToHost(serviceNameResolver *ServiceNameResolver,
 	requestID uint64, cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
 	var err error
 	var host *url.URL
-	var rpcResult *RPCResult
-	startTime := time.Now()
 	bo := backoff.NewDefaultBackoffWithInitialBackOff(100 * time.Millisecond)
 	// we can retry these requests because this kind of request is
 	// not specific to any particular broker
-	for time.Since(startTime) < c.requestTimeout {
+	opFn := func() (*RPCResult, error) {
 		host, err = (*serviceNameResolver).ResolveHost()
 		if err != nil {
 			c.log.WithError(err).Errorf("rpc client failed to resolve host")
 			return nil, err
 		}
-		rpcResult, err = c.Request(host, host, requestID, cmdType, message)
-		// success we got a response
-		if err == nil {
-			break
-		}
+		return c.Request(host, host, requestID, cmdType, message)
+	}
 
+	ctx, cancel := context.WithTimeout(context.Background(), c.requestTimeout)
+	defer cancel()
+
+	rpcResult, err := Retry(ctx, opFn, func(_ error) time.Duration {
 		retryTime := bo.Next()
 		c.log.Debugf("Retrying request in {%v} with timeout in {%v}", retryTime, c.requestTimeout)
-		time.Sleep(retryTime)
-	}
+		return retryTime
+	})
 
 	return rpcResult, err
 }
@@ -152,7 +157,13 @@ func (c *rpcClient) RequestToHost(serviceNameResolver *ServiceNameResolver, requ
 
 func (c *rpcClient) Request(logicalAddr *url.URL, physicalAddr *url.URL, requestID uint64,
 	cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
-	cnx, err := c.pool.GetConnection(logicalAddr, physicalAddr)
+	return c.RequestWithCnxKeySuffix(logicalAddr, physicalAddr, c.pool.GenerateRoundRobinIndex(),
+		requestID, cmdType, message)
+}
+
+func (c *rpcClient) RequestWithCnxKeySuffix(logicalAddr *url.URL, physicalAddr *url.URL, cnxKeySuffix int32,
+	requestID uint64, cmdType pb.BaseCommand_Type, message proto.Message) (*RPCResult, error) {
+	cnx, err := c.pool.GetConnection(logicalAddr, physicalAddr, cnxKeySuffix)
 	if err != nil {
 		return nil, err
 	}
@@ -240,7 +251,7 @@ func (c *rpcClient) NewLookupService(url *url.URL) (LookupService, error) {
 	case "pulsar", "pulsar+ssl":
 		serviceNameResolver := NewPulsarServiceNameResolver(url)
 		return NewLookupService(c, url, serviceNameResolver,
-			c.tlsConfig != nil, c.listenerName, c.log, c.metrics), nil
+			c.tlsConfig != nil, c.listenerName, c.lookupProperties, c.log, c.metrics), nil
 	case "http", "https":
 		serviceNameResolver := NewPulsarServiceNameResolver(url)
 		httpClient, err := NewHTTPClient(url, serviceNameResolver, c.tlsConfig,
