@@ -90,14 +90,24 @@ type Namespaces interface {
 	// GetSchemaValidationEnforced returns schema validation enforced for namespace
 	GetSchemaValidationEnforced(namespace utils.NameSpaceName) (bool, error)
 
-	// SetSchemaAutoUpdateCompatibilityStrategy sets the strategy used to check the a new schema provided
+	// SetSchemaAutoUpdateCompatibilityStrategy sets the strategy used to check the new schema provided
 	// by a producer is compatible with the current schema before it is installed
 	SetSchemaAutoUpdateCompatibilityStrategy(namespace utils.NameSpaceName,
+		strategy utils.SchemaAutoUpdateCompatibilityStrategy) error
+
+	// GetSchemaAutoUpdateCompatibilityStrategy returns the strategy used to check the new schema provided
+	// by a producer is compatible with the current schema before it is installed
+	GetSchemaAutoUpdateCompatibilityStrategy(namespace utils.NameSpaceName) (
+		utils.SchemaAutoUpdateCompatibilityStrategy, error)
+
+	// SetSchemaCompatibilityStrategy sets the strategy used to check the new schema provided
+	// by a producer is compatible with the current schema before it is installed
+	SetSchemaCompatibilityStrategy(namespace utils.NameSpaceName,
 		strategy utils.SchemaCompatibilityStrategy) error
 
-	// GetSchemaAutoUpdateCompatibilityStrategy returns the strategy used to check the a new schema provided
+	// GetSchemaCompatibilityStrategy returns the strategy used to check the new schema provided
 	// by a producer is compatible with the current schema before it is installed
-	GetSchemaAutoUpdateCompatibilityStrategy(namespace utils.NameSpaceName) (utils.SchemaCompatibilityStrategy, error)
+	GetSchemaCompatibilityStrategy(namespace utils.NameSpaceName) (utils.SchemaCompatibilityStrategy, error)
 
 	// ClearOffloadDeleteLag clears the offload deletion lag for a namespace.
 	ClearOffloadDeleteLag(namespace utils.NameSpaceName) error
@@ -295,6 +305,15 @@ type Namespaces interface {
 	// RemoveSubscriptionExpirationTime removes subscription expiration time from a namespace,
 	// defaulting to broker settings
 	RemoveSubscriptionExpirationTime(namespace utils.NameSpaceName) error
+
+	// UpdateProperties updates the properties of a namespace
+	UpdateProperties(namespace utils.NameSpaceName, properties map[string]string) error
+
+	// GetProperties returns the properties of a namespace
+	GetProperties(namespace utils.NameSpaceName) (map[string]string, error)
+
+	// RemoveProperties clears the properties of a namespace
+	RemoveProperties(namespace utils.NameSpaceName) error
 }
 
 type namespaces struct {
@@ -497,13 +516,13 @@ func (n *namespaces) GetSchemaValidationEnforced(namespace utils.NameSpaceName)
 }
 
 func (n *namespaces) SetSchemaAutoUpdateCompatibilityStrategy(namespace utils.NameSpaceName,
-	strategy utils.SchemaCompatibilityStrategy) error {
+	strategy utils.SchemaAutoUpdateCompatibilityStrategy) error {
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "schemaAutoUpdateCompatibilityStrategy")
 	return n.pulsar.Client.Put(endpoint, strategy.String())
 }
 
 func (n *namespaces) GetSchemaAutoUpdateCompatibilityStrategy(namespace utils.NameSpaceName) (
-	utils.SchemaCompatibilityStrategy, error) {
+	utils.SchemaAutoUpdateCompatibilityStrategy, error) {
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "schemaAutoUpdateCompatibilityStrategy")
 	b, err := n.pulsar.Client.GetWithQueryParams(endpoint, nil, nil, false)
 	if err != nil {
@@ -516,6 +535,26 @@ func (n *namespaces) GetSchemaAutoUpdateCompatibilityStrategy(namespace utils.Na
 	return s, nil
 }
 
+func (n *namespaces) SetSchemaCompatibilityStrategy(namespace utils.NameSpaceName,
+	strategy utils.SchemaCompatibilityStrategy) error {
+	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "schemaCompatibilityStrategy")
+	return n.pulsar.Client.Put(endpoint, strategy.String())
+}
+
+func (n *namespaces) GetSchemaCompatibilityStrategy(namespace utils.NameSpaceName) (
+	utils.SchemaCompatibilityStrategy, error) {
+	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "schemaCompatibilityStrategy")
+	b, err := n.pulsar.Client.GetWithQueryParams(endpoint, nil, nil, false)
+	if err != nil {
+		return "", err
+	}
+	s, err := utils.ParseSchemaCompatibilityStrategy(strings.ReplaceAll(string(b), "\"", ""))
+	if err != nil {
+		return "", err
+	}
+	return s, nil
+}
+
 func (n *namespaces) ClearOffloadDeleteLag(namespace utils.NameSpaceName) error {
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "offloadDeletionLagMs")
 	return n.pulsar.Client.Delete(endpoint)
@@ -940,3 +979,20 @@ func (n *namespaces) RemoveSubscriptionExpirationTime(namespace utils.NameSpaceN
 	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "subscriptionExpirationTime")
 	return n.pulsar.Client.Delete(endpoint)
 }
+
+func (n *namespaces) UpdateProperties(namespace utils.NameSpaceName, properties map[string]string) error {
+	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "properties")
+	return n.pulsar.Client.Put(endpoint, properties)
+}
+
+func (n *namespaces) GetProperties(namespace utils.NameSpaceName) (map[string]string, error) {
+	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "properties")
+	properties := make(map[string]string)
+	err := n.pulsar.Client.Get(endpoint, &properties)
+	return properties, err
+}
+
+func (n *namespaces) RemoveProperties(namespace utils.NameSpaceName) error {
+	endpoint := n.pulsar.endpoint(n.basePath, namespace.String(), "properties")
+	return n.pulsar.Client.Delete(endpoint)
+}
